==> tmgmt_extension_suit-8.x-1.3.tar.gz: tmgmt_extension_suit/src/Utils/UniqueQueueItem.php <==
<?php

/**
 * @file
 * Contains QueueUniqueItem service class.
 */

namespace Drupal\tmgmt_extension_suit\Utils;

use Drupal\Core\Database\Connection;
use Drupal\Core\Queue\QueueFactory;
use Psr\Log\LoggerInterface;

class UniqueQueueItem {

  /**
   * @var \Drupal\Core\Queue\QueueFactory
   */
  private $queueFactory;

  /**
   * @var \Psr\Log\LoggerInterface
   */
  private $logger;

  /**
   * @var \Drupal\Core\Database\Connection
   */
  private $databaseConnection;

  public function __construct(QueueFactory $queueFactory, LoggerInterface $logger, Connection $databaseConnection) {
    $this->queueFactory = $queueFactory;
    $this->logger = $logger;
    $this->databaseConnection = $databaseConnection;
  }

  /**
   * Adds item into a queue only if it's unique.
   *
   * @param string $queueName
   *   Queue name.
   * @param array $data
   *   Data to be added.
   */
  public function addItem($queueName, $data) {
    $serializedData = serialize($data);
    $count = $this->databaseConnection->select('queue', 'q')
      ->condition('q.name', $queueName)
      ->condition('q.data', $serializedData)
      ->countQuery()
      ->execute()
      ->fetchField();

    if ($count != 0) {
      return;
    }

    $result = $this->queueFactory->get($queueName)->createItem($data);

    if ($result) {
      $this->logger->info('New unique item has been added into the "@queue" queue. Serialized queue item: @item.', [
        '@queue' => $queueName,
        '@item' => $serializedData,
      ]);
    }
  }

}

==> tmgmt_extension_suit-8.x-2.4.tar.gz: tmgmt_extension_suit/src/Utils/UniqueQueueItem.php <==
<?php

/**
 * @file
 * Contains QueueUniqueItem service class.
 */

namespace Drupal\tmgmt_extension_suit\Utils;

use Drupal\Core\Database\Connection;
use Drupal\Core\Queue\QueueFactory;
use Psr\Log\LoggerInterface;

class UniqueQueueItem {

  /**
   * @var \Drupal\Core\Queue\QueueFactory
   */
  private $queueFactory;

  /**
   * @var \Psr\Log\LoggerInterface
   */
  private $logger;

  /**
   * @var \Drupal\Core\Database\Connection
   */
  private $databaseConnection;

  public function __construct(QueueFactory $queue_factory, LoggerInterface $logger, Connection $database_connection) {
    $this->queueFactory = $queue_factory;
    $this->logger = $logger;
    $this->databaseConnection = $database_connection;
  }

  /**
   * Adds item into a queue only if it's unique.
   *
   * @param string $queue_name
   *   Queue name.
   * @param array $data
   *   Data to be added.
   */
  public function addItem($queue_name, $data) {
    $serialized_data = serialize($data);
    $count = $this->databaseConnection->select('queue', 'q')
      ->condition('q.name', $queue_name)
      ->condition('q.data', $serialized_data)
      ->countQuery()
      ->execute()
      ->fetchField();

    if ($count != 0) {
      return;
    }

    $result = $this->queueFactory->get($queue_name)->createItem($data);

    if ($result) {
      $this->logger->info('New unique item has been added into the "@queue" queue. Serialized queue item: @item.', [
        '@queue' => $queue_name,
        '@item' => $serialized_data,
      ]);
    }
  }

}
